mapping between variables, functions to load them, dependent variables, and available verifications compatible with GCAM Europe 8.7.
Examples
if (FALSE) { # \dontrun{
library(gcamreport)
gcamreport::var_fun_map_vEurope8.7
} # }
mapping between variables, functions to load them, dependent variables, and available verifications compatible with GCAM Europe 8.7.
if (FALSE) { # \dontrun{
library(gcamreport)
gcamreport::var_fun_map_vEurope8.7
} # }